==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/language/1/am_default/my_library.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common_my.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_contents'] = 						"contents";
$lang['hdr_history'] = 							"history";


//A HREF TAGS (links)
$lang['href_contents'] = 						"contents";
$lang['href_history'] = 						"history";
$lang['href_default'] = 						"first page";


//ERRORS
$lang['err_no_contents'] = 						"Sorry, this scrapbook has no items.";
$lang['err_no_history'] = 						"Sorry, this scrapbook item has no historical versions.";


//BODY TEXT
$lang['txt_default'] = 							"default";

?>

==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/language/1/am_default/my_library.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_contents'] = 						"contents";
$lang['hdr_history'] = 							"history";
$lang['hdr_library'] = 							"library";


//A HREF TAGS (links)
$lang['href_contents'] = 						"contents";
$lang['href_history'] = 						"history";
$lang['href_default'] = 						"first page";
$lang['href_wiki_first_page'] = 				"start your library";


//ERRORS
$lang['err_no_contents'] = 						"Sorry, this library is empty.";
$lang['err_no_history'] = 						"Sorry, this library item has no history.";


//BODY TEXT
$lang['txt_default'] = 							"default";

?>
